==> zio-aws-batch_2.13-5.17.104.13-sources.jar: zio/aws/batch/model/Tmpfs.scala <==
package zio.aws.batch.model
import zio.aws.batch.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class Tmpfs(
    containerPath: String,
    size: Integer,
    mountOptions: Option[Iterable[String]] = None
) {
  def buildAwsValue(): software.amazon.awssdk.services.batch.model.Tmpfs = {
    import Tmpfs.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.batch.model.Tmpfs
      .builder()
      .containerPath(containerPath: java.lang.String)
      .size(Integer.unwrap(size): java.lang.Integer)
      .optionallyWith(
        mountOptions.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.mountOptions)
      .build()
  }
  def asReadOnly: zio.aws.batch.model.Tmpfs.ReadOnly =
    zio.aws.batch.model.Tmpfs.wrap(buildAwsValue())
}
object Tmpfs {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.batch.model.Tmpfs] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.batch.model.Tmpfs = zio.aws.batch.model
      .Tmpfs(containerPath, size, mountOptions.map(value => value))
    def containerPath: String
    def size: Integer
    def mountOptions: Option[List[String]]
    def getContainerPath: ZIO[Any, Nothing, String] = ZIO.succeed(containerPath)
    def getSize: ZIO[Any, Nothing, Integer] = ZIO.succeed(size)
    def getMountOptions: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("mountOptions", mountOptions)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.batch.model.Tmpfs
  ) extends zio.aws.batch.model.Tmpfs.ReadOnly {
    override val containerPath: String = impl.containerPath(): String
    override val size: Integer =
      zio.aws.batch.model.primitives.Integer(impl.size())
    override val mountOptions: Option[List[String]] = scala
      .Option(impl.mountOptions())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.batch.model.Tmpfs
  ): zio.aws.batch.model.Tmpfs.ReadOnly = new Wrapper(impl)
}

==> zio-aws-batch_2.13-5.17.157.2-sources.jar: zio/aws/batch/model/Tmpfs.scala <==
package zio.aws.batch.model
import zio.aws.batch.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class Tmpfs(
    containerPath: String,
    size: Integer,
    mountOptions: Option[Iterable[String]] = None
) {
  def buildAwsValue(): software.amazon.awssdk.services.batch.model.Tmpfs = {
    import Tmpfs.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.batch.model.Tmpfs
      .builder()
      .containerPath(containerPath: java.lang.String)
      .size(size: java.lang.Integer)
      .optionallyWith(
        mountOptions.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.mountOptions)
      .build()
  }
  def asReadOnly: zio.aws.batch.model.Tmpfs.ReadOnly =
    zio.aws.batch.model.Tmpfs.wrap(buildAwsValue())
}
object Tmpfs {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.batch.model.Tmpfs] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.batch.model.Tmpfs = zio.aws.batch.model
      .Tmpfs(containerPath, size, mountOptions.map(value => value))
    def containerPath: String
    def size: Integer
    def mountOptions: Option[List[String]]
    def getContainerPath: ZIO[Any, Nothing, String] = ZIO.succeed(containerPath)
    def getSize: ZIO[Any, Nothing, Integer] = ZIO.succeed(size)
    def getMountOptions: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("mountOptions", mountOptions)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.batch.model.Tmpfs
  ) extends zio.aws.batch.model.Tmpfs.ReadOnly {
    override val containerPath: String = impl.containerPath(): String
    override val size: Integer = impl.size(): Integer
    override val mountOptions: Option[List[String]] = scala
      .Option(impl.mountOptions())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.batch.model.Tmpfs
  ): zio.aws.batch.model.Tmpfs.ReadOnly = new Wrapper(impl)
}
